Public methods
Method new()
Usage
FirebaseOauthProviders$new(
persistence = c("session", "local", "memory"),
config_path = "firebase.rds",
language_code = NULL,
session = shiny::getDefaultReactiveDomain()
)Arguments
persistenceHow the auth should persit: none, the user has to sign in at every visit,
session will only persist in current tab, local persist even when window is closed.
config_pathPath to the configuration file as created by firebase_config.
language_codeSets the language to use for the UI.
Supported languages are listed here.
Set to browser to use the default browser language of the user.
sessionA valid shiny session.
Details
Initialiases Firebase Email Link
Initialises the Firebase application client-side.
Method set_provider()
Usage
FirebaseOauthProviders$set_provider(provider)
Arguments
providerThe provider to user, e.g.: microsoft.com, yahoo.com or google.com.
Details
Define provider to use
Returns
self
Method launch()
Usage
FirebaseOauthProviders$launch(flow = c("popup", "redirect"))Arguments
flowAuthentication flow, either popup or redirect.
Details
Launch sign in with Google.
Returns
self
Method clone()
The objects of this class are cloneable with this method.
Usage
FirebaseOauthProviders$clone(deep = FALSE)
Arguments
deepWhether to make a deep clone.